package format

import "cuelang.org/go/internal/core/format"

Package format provides functionality for pretty-printing CUE values. These types need to be in a separate package to avoid import cycles.

Index

Types

type Printer

type Printer interface {
	// ReplaceArg is a function that may be called to replace arguments to
	// errors. This is mostly used for cycle detection.
	ReplaceArg(x any) (r any, wasReplaced bool)
}

Printer is the interface used to print CUE values. The only implementation so far is the one in internal/core/debug. Note that most packages cannot directly import the debug package.

Source Files

printer.go

Version
v0.15.1 (latest)
Published
Nov 21, 2025
Platform
linux/amd64
Last checked
4 months ago

Tools for package owners.