json

package
v0.16.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Marshal added in v0.6.0

func Marshal(v any) ([]byte, error)

Marshal is a replacement for json.Marshal without HTML escaping.

func PatchExpr added in v0.16.0

func PatchExpr(n ast.Node, patchPos func(n ast.Node))

PatchExpr simplifies the AST parsed from JSON. TODO: some of the modifications are already done in format, but are a package deal of a more aggressive simplify. Other pieces of modification should probably be moved to format.

Types

This section is empty.

Jump to